@@ -50,7 +50,7 @@ if (isset($allow_compose)) {
 	<div class="box">
 		<div class="box_top">
 			<div class="content">
-				<?php echo $lang['hdr_message'];?><br />
+				<h1><?php echo $lang['hdr_message'];?></h1>
 			</div>
 		</div>
 	
@@ -153,7 +153,7 @@ if (isset($allow_compose)) {
 	<div class="box">
 		<div class="box_top">
 			<div class="content">
-				<?php echo $lang['hdr_recipient'];?><br />
+				<h1><?php echo $lang['hdr_recipient'];?></h1>
 			</div>
 		</div>
 					
@@ -196,7 +196,7 @@ if (isset($allow_compose)) {
 				<input title="<?php echo $hover_title;?>" type="checkbox" name="to_identity_ids[]" value="<?php echo $id['identity_id'];?>" onClick="javascript:setToNames();" <?php echo $checked;?> />
 				<input type="hidden" name="to_identity_names[]" value="<?php echo $id['identity_nic'];?>" />
 				<span title="<?php echo $hover_title;?>">
-				<?php echo $id['identity_nic'];?></span><br />
+				<?php echo dots($id['identity_nic'],20);?></span><br />
 				<?php
 				endforeach;
 				}
@@ -252,7 +252,7 @@ else {
 <div class="box">
 	<div class="box_top">
 		<div class="content">
-			<?php echo $lang['hdr_no_pref'];?><br />
+			<h1><?php echo $lang['hdr_no_pref'];?></h1>
 		</div>
 	</div>
 					
